antares.apps.client.api package
===============================

Submodules
----------

antares.apps.client.api.api\_branch\_list\_address\_view module
---------------------------------------------------------------

.. automodule:: antares.apps.client.api.api_branch_list_address_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.api.api\_branch\_list\_emails\_view module
--------------------------------------------------------------

.. automodule:: antares.apps.client.api.api_branch_list_emails_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.api.api\_branch\_list\_social\_network\_view module
-----------------------------------------------------------------------

.. automodule:: antares.apps.client.api.api_branch_list_social_network_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.api.api\_branch\_list\_telephone\_view module
-----------------------------------------------------------------

.. automodule:: antares.apps.client.api.api_branch_list_telephone_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.api.api\_business\_clasification\_view module
-----------------------------------------------------------------

.. automodule:: antares.apps.client.api.api_business_clasification_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.api.api\_client\_attributes\_view module
------------------------------------------------------------

.. automodule:: antares.apps.client.api.api_client_attributes_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.api.api\_client\_id\_view module
----------------------------------------------------

.. automodule:: antares.apps.client.api.api_client_id_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.api.api\_client\_relations\_view module
-----------------------------------------------------------

.. automodule:: antares.apps.client.api.api_client_relations_view
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.client.api
   :members:
   :undoc-members:
   :show-inheritance:
